@@ -67,6 +67,20 @@ gboolean     thunar_g_file_get_free_space           (GFile                *file,
 gchar       *thunar_g_file_get_free_space_string    (GFile                *file,
                                                      gboolean              file_size_binary);
 
+gboolean     thunar_g_file_copy                     (GFile                *source,
+                                                     GFile                *destination,
+                                                     GFileCopyFlags        flags,
+                                                     gboolean              use_partial,
+                                                     GCancellable         *cancellable,
+                                                     GFileProgressCallback progress_callback,
+                                                     gpointer              progress_callback_data,
+                                                     GError              **error);
+
+gboolean     thunar_g_file_compare_checksum         (GFile                *file_a,
+                                                     GFile                *file_b,
+                                                     GCancellable         *cancellable,
+                                                     GError              **error);
+
 /**
  * THUNAR_TYPE_G_FILE_LIST:
  *
@@ -80,6 +94,9 @@ GType        thunar_g_file_list_get_type               (void);
 GList       *thunar_g_file_list_new_from_string        (const gchar       *string);
 gchar      **thunar_g_file_list_to_stringv             (GList             *list);
 GList       *thunar_g_file_list_get_parents            (GList             *list);
+gboolean     thunar_g_file_is_descendant               (GFile             *descendant,
+                                                        GFile             *ancestor);
+
 
 /* deep copy jobs for GLists */
 #define      thunar_g_list_append_deep(list,object)    g_list_append (list, g_object_ref (G_OBJECT (object)))
@@ -97,7 +114,6 @@ gboolean     thunar_g_app_info_should_show             (GAppInfo          *info)
 
 gboolean     thunar_g_vfs_metadata_is_supported        (void);
 
-
 G_END_DECLS
 
 #endif /* !__THUNAR_GIO_EXTENSIONS_H__ */
