@@ -43,7 +43,6 @@ enum
 {
   ASK,
   ASK_REPLACE,
-  ASK_JOBS,
   FILES_READY,
   NEW_FILES,
   FROZEN,
@@ -204,22 +203,6 @@ thunar_job_class_init (ThunarJobClass *klass)
                   g_cclosure_marshal_VOID__POINTER,
                   G_TYPE_NONE, 1, G_TYPE_POINTER);
 
-  /**
-   * ThunarJob::ask-jobs:
-   * @job      : a #ThunarJob.
-   *
-   * Emitted to ask the running job list.
-   *
-   * Return value: GList* of running jobs.
-   **/
-  job_signals[ASK_JOBS] =
-    g_signal_new (I_("ask-jobs"),
-                  G_TYPE_FROM_CLASS (klass),
-                  G_SIGNAL_NO_HOOKS, 0,
-                  NULL, NULL,
-                  g_cclosure_marshal_generic,
-                  G_TYPE_POINTER, 0);
-
   /**
    * ThunarJob::frozen:
    * @job       : a #ThunarJob.
@@ -704,19 +687,6 @@ thunar_job_new_files (ThunarJob   *job,
 
 
 
-GList *
-thunar_job_ask_jobs (ThunarJob *job)
-{
-  GList* jobs = NULL;
-
-  _thunar_return_val_if_fail (THUNAR_IS_JOB (job), NULL);
-
-  exo_job_emit (EXO_JOB (job), job_signals[ASK_JOBS], 0, &jobs);
-  return jobs;
-}
-
-
-
 void
 thunar_job_set_total_files (ThunarJob *job,
                             GList     *total_files)
@@ -773,7 +743,7 @@ thunar_job_freeze (ThunarJob *job)
 {
   _thunar_return_if_fail (THUNAR_IS_JOB (job));
   job->priv->frozen = TRUE;
-  exo_job_emit (EXO_JOB (job), job_signals[FROZEN], 0);
+  g_signal_emit (EXO_JOB (job), job_signals[FROZEN], 0);
 }
 
 
@@ -783,7 +753,7 @@ thunar_job_unfreeze (ThunarJob *job)
 {
   _thunar_return_if_fail (THUNAR_IS_JOB (job));
   job->priv->frozen = FALSE;
-  exo_job_emit (EXO_JOB (job), job_signals[UNFROZEN], 0);
+  g_signal_emit (EXO_JOB (job), job_signals[UNFROZEN], 0);
 }
 
 
