@@ -460,7 +460,6 @@ ttj_copy_file (ThunarTransferJob *job,
                GFile             *source_file,
                GFile             *target_file,
                GFileCopyFlags     copy_flags,
-               gboolean           merge_directories,
                GError           **error)
 {
   GFileInfo *info;
@@ -585,9 +584,8 @@ ttj_copy_file (ThunarTransferJob *job,
               && target_type == G_FILE_TYPE_DIRECTORY))
         {
           /* we tried to overwrite a directory with a directory. this normally results
-           * in a merge. ignore the error if we actually *want* to merge */
-          if (merge_directories)
-            g_clear_error (&err);
+           * in a merge. ignore that error, since we actually *want* to merge */
+          g_clear_error (&err);
         }
       else if (err->code == G_IO_ERROR_WOULD_RECURSE)
         {
@@ -709,7 +707,7 @@ thunar_transfer_job_copy_file (ThunarTransferJob *job,
       if (err == NULL)
         {
           /* try to copy the file from source file to the duplicate file */
-          if (ttj_copy_file (job, source_file, target, copy_flags, FALSE, &err))
+          if (ttj_copy_file (job, source_file, target, copy_flags, &err))
             return target;
           else /* go to error case */
             g_object_unref (target);
@@ -833,12 +831,12 @@ thunar_transfer_job_copy_node (ThunarTransferJob  *job,
     {
       fs_type = g_file_info_get_attribute_string (fs_info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
       use_fat_name_scheme =
-        !strcmp (fs_type, "fat")   ||
-        !strcmp (fs_type, "vfat")  ||
-        !strcmp (fs_type, "fuse")  ||
-        !strcmp (fs_type, "ntfs")  ||
-        !strcmp (fs_type, "msdos") ||
-        !strcmp (fs_type, "msdosfs");
+        !g_strcmp0 (fs_type, "fat")   ||
+        !g_strcmp0 (fs_type, "vfat")  ||
+        !g_strcmp0 (fs_type, "fuse")  ||
+        !g_strcmp0 (fs_type, "ntfs")  ||
+        !g_strcmp0 (fs_type, "msdos") ||
+        !g_strcmp0 (fs_type, "msdosfs");
     }
   else
     {
@@ -883,19 +881,19 @@ thunar_transfer_job_copy_node (ThunarTransferJob  *job,
           base_name = g_file_get_basename (target_file);
           g_clear_object (&target_file);
 
-          /* replace invalid chars */
+          /* replace character which are invalid for FAT filenames */
           g_strdelimit (g_strchomp (base_name),
                         "/:*?\"<>\\|",
                         '_');
 
-          /* character 0~31 is invalid */
+          /* ASCII characters 0~31 are as well invalid for FAT filenames */
           for (int i = 0; base_name[i] != '\0'; i++)
             {
-              if (base_name[i] < 32)
+              if (base_name[i] >= 0 && base_name[i] < 32)
                 base_name[i] = '_';
             }
 
-          /* avoid reserved names */
+          /* avoid FAT reserved names */
           if (g_regex_match (windows_reserved_name, base_name, 0, NULL))
             {
               gchar *tmp = base_name;
